@@ -71,10 +71,7 @@ windows:
 macos:
   allowed-system-libs: .*  # System libs on macos are OK (such as bz2 etc)
   env:
-    MACOSX_DEPLOYMENT_TARGET: 10.14
-  arm64:
-    env:
-      MACOSX_DEPLOYMENT_TARGET: 12
+    MACOSX_DEPLOYMENT_TARGET: 13  # Ventura, released June 2022
 """
 
 
@@ -271,6 +268,9 @@ class Config:
             if fc:
                 return fc
 
+        if runez.DRYRUN:
+            return desired
+
     def ensure_main_file_symlinks(self, module):
         folder = module.install_folder
         version = module.version
