@@ -497,6 +497,34 @@ class PythonInspector:
         report = runez.joined(report or self.output, delimiter="\n")
         return runez.joined(report, delimiter="\n")
 
+    @staticmethod
+    def parsed_version(output):
+        """
+        Args:
+            output (str | None): Output to parse
+
+        Returns:
+            (str | None): Simplified version number reported
+        """
+        if output:
+            for line in output.splitlines():
+                line = line.strip()
+                if line:
+                    rx = re.compile(r"^.*?([\d.]+).*$")
+                    m = rx.match(line)
+                    if m:
+                        version = m.group(1)
+                        return version and version.strip()
+
+    @staticmethod
+    def tool_version(tool_name):
+        """Simplified --version extracted from tool with 'tool_name'"""
+        full_path = runez.which(tool_name)
+        if full_path:
+            output = runez.run(full_path, "--version", fatal=False, dryrun=False)
+            if output:
+                return PythonInspector.parsed_version(output.output or output.error)
+
 
 def _find_parent_subfolder(folder, basename):
     while folder and len(folder.parts) > 1:
@@ -522,7 +550,7 @@ class FullSoReport:
                 continue
 
             info = SoInfo(inspector, path)
-            if path.name.startswith("libpython"):  # pragma: no cover (would need to do a fully build with libpython.so...)
+            if path.name.startswith("libpython"):  # pragma: no cover (would need to do a full build with libpython.so...)
                 self.libpython_so.append(info)
 
             self.lib_tracker.add(info)
@@ -545,7 +573,7 @@ class FullSoReport:
                 if uses_system:
                     return "Uses system libs: %s" % runez.red(runez.joined(uses_system))
 
-        if self.problematic:
+        if self.problematic:  # pragma: no cover (don't have a handy problematic python test case)
             return runez.joined(self.problematic.represented())
 
         if not runez.DRYRUN and not self.ok:
